@@ -24,6 +24,8 @@ use strict;
 
 package RAMCMS;
 
+use File::Basename;
+
 # Purpose: determine when the requested page was last updated, and format as string.
 # Santax: str $updated_show = ramcms_last_update_time ( str $page )
 # Where: 
@@ -151,6 +153,15 @@ sub ramcms_page_template_parser
 	my $body=shift;
 	my $copyright=shift;
 	my $curdir=shift;
+	
+	my $protocol='http://';
+	if(defined($ENV{'HTTPS'}) and lc($ENV{'HTTPS'}) eq 'on')
+	{
+		$protocol='https://';
+	}
+	
+	# parse the $page_template information.
+	$$page_template=str_replace('[[baseurl]]',$protocol.$ENV{'SERVER_NAME'}.dirname($ENV{'SCRIPT_NAME'}).'/',$$page_template);
 	# parse the $page_template information.
 	#$$page_template=str_replace('[[body]]',$body,$$page_template);
 	$$page_template =~ s/\[\[body\]\]/$body/g;
@@ -168,7 +179,7 @@ sub ramcms_page_template_parser
 	#$$page_template=str_replace('[[updated]]',$updated_show,$$page_template);
 	$$page_template =~ s/\[\[updated\]\]/$updated_show/g;
 	#$$page_template=str_replace('[[ver]]','0.2.0',$$page_template);
-	$$page_template =~ s/\[\[ver\]\]/0.2.0/g;
+	$$page_template =~ s/\[\[ver\]\]/0.2.5/g;
 	
 	#return $page_template;
 }
@@ -256,6 +267,12 @@ sub ramcms_bbcode_parser
 	
 	### Complex BBCode ###
 	
+	# handles [link]page-name[/link]
+	$$body =~ s/\[link\](.+?)\[\/link\]/<a href=".\/?page=${1}">${1}<\/a>/gs;
+	
+	# handles [link=page-name]Click Blah[/link]
+	$$body =~ s/\[link=(.+?)\](.+?)\[\/link\]/<a href=".\/?page=${1}">${2}<\/a>/gs;
+	
 	# handles [url]http://example.com/blah..[/url]
 	$$body =~ s/\[url\](.+?)\[\/url\]/<a href="${1}">${1}<\/a>/gs;
 	
